"""Leaderboard group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

LEADERBOARD_TASKS = {
    "leaderboard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_mmlu_pro": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_boolean_expressions": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_causal_judgement": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_date_understanding": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_disambiguation_qa": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_formal_fallacies": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_geometric_shapes": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_hyperbaton": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_logical_deduction_five_objects": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_logical_deduction_seven_objects": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_logical_deduction_three_objects": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_movie_recommendation": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_navigate": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_object_counting": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_penguins_in_a_table": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_reasoning_about_colored_objects": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_ruin_names": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_salient_translation_error_detection": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_snarks": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_sports_understanding": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_temporal_sequences": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_tracking_shuffled_objects_five_objects": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_tracking_shuffled_objects_seven_objects": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_tracking_shuffled_objects_three_objects": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_bbh_web_of_lies": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_gpqa": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_gpqa_diamond": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_gpqa_extended": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_gpqa_main": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_algebra_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_counting_and_prob_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_geometry_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_intermediate_algebra_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_num_theory_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_prealgebra_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_math_precalculus_hard": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_ifeval": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_musr": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_musr_murder_mysteries": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_musr_object_placements": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
    "leaderboard_musr_team_allocation": f"{BASE_IMPORT}leaderboard:LeaderboardExtractor",
}
