"""Scrolls group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval.lm_task_extractors."

SCROLLS_TASKS = {
    "scrolls": f"{BASE_IMPORT}scrolls:ScrollsExtractor",
}
